Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(29)

Unified Diff: content/renderer/media/video_capture_service.h

Issue 960103002: Rename VideoCaptureImplManager to VideoCaptureService Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix some nits Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/media/video_capture_service.h
diff --git a/content/renderer/media/video_capture_impl_manager.h b/content/renderer/media/video_capture_service.h
similarity index 92%
rename from content/renderer/media/video_capture_impl_manager.h
rename to content/renderer/media/video_capture_service.h
index 5bcc7b2a6c3b24215bfcacd2d18cb15807f3a647..35a57e034aae0c3e6df9ff60b8bc9f76502fac4b 100644
--- a/content/renderer/media/video_capture_impl_manager.h
+++ b/content/renderer/media/video_capture_service.h
@@ -2,15 +2,13 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// TODO(hclam): This class should be renamed to VideoCaptureService.
-
// This class provides access to a video capture device in the browser
// process through IPC. The main function is to deliver video frames
// to a client.
//
// THREADING
//
// VideoCaptureImplManager lives only on the render thread. All methods
// must be called on this thread.
//
// VideoFrames are delivered on the IO thread. Callbacks provided by
@@ -39,10 +37,10 @@ namespace content {
class VideoCaptureImpl;
no sievers 2015/03/06 19:36:09 drop this?
class VideoCaptureMessageFilter;
-class CONTENT_EXPORT VideoCaptureImplManager {
+class CONTENT_EXPORT VideoCaptureService {
public:
- VideoCaptureImplManager();
- virtual ~VideoCaptureImplManager();
+ VideoCaptureService();
+ virtual ~VideoCaptureService();
// Open a device associated with the session ID.
// This method must be called before any methods with the same ID
@@ -123,9 +121,9 @@ class CONTENT_EXPORT VideoCaptureImplManager {
// Bound to the render thread.
// NOTE: Weak pointers must be invalidated before all other member variables.
- base::WeakPtrFactory<VideoCaptureImplManager> weak_factory_;
+ base::WeakPtrFactory<VideoCaptureService> weak_factory_;
- DISALLOW_COPY_AND_ASSIGN(VideoCaptureImplManager);
+ DISALLOW_COPY_AND_ASSIGN(VideoCaptureService);
};
} // namespace content
« no previous file with comments | « content/renderer/media/video_capture_impl_manager_unittest.cc ('k') | content/renderer/media/video_capture_service.cc » ('j') | no next file with comments »
@@ -2,15 +2,13 @@
// THREADING
//
-// VideoCaptureImplManager lives only on the render thread. All methods
+// VideoCaptureService lives only on the render thread. All methods
// must be called on this thread.
//

Powered by Google App Engine
This is Rietveld 408576698